﻿Imports System.Drawing.Printing

Public Class Form1

    ' File-related variables ...
    Private mstrCustFileName As String = My.Application.Info.DirectoryPath & "\customer.txt"
    Private mintCustFileNbr As Short

    ' Fields of the input record ...
    Private mstrFirstName As String
    Private mstrLastName As String
    Private mstrAddr As String
    Private mstrCity As String
    Private mstrState As String
    Private mstrZip As String

    ' Printing-related variables...
    Private mobjPrintFont As Font
    Private msngLinesPerPage As Single = 0
    Private msngVerticalPosition As Single = 0
    Private mintLineCount As Integer = 0
    Private mintPageCount As Integer = 0
    Private msngLeftMargin As Single
    Private msngTopMargin As Single

    Private Sub btnPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnPrint.Click

        ' Declare an object for the PrintDocument class...
        Dim objPrintDocument As PrintDocument = New PrintDocument()

        ' Set the print font...
        mobjPrintFont = New Font("Courier New", 10)

        ' Add an event handler for the PrintPage event of the
        ' objPrintDocument object...
        AddHandler objPrintDocument.PrintPage, AddressOf objPrintDocument_PrintPage

        ' open the customer data file ...
        mintCustFileNbr = FreeFile()
        FileOpen(mintCustFileNbr, mstrCustFileName, OpenMode.Input)

        ' Print the output (the statement below causes all the "action" to take place 
        ' in the objPrintDocument_PrintPage event) ...
        objPrintDocument.Print()

        ' close the input file
        FileClose(mintCustFileNbr)

    End Sub

    Private Sub btnExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExit.Click

        ' unload the form
        Me.Close()

    End Sub

    Private Sub objPrintDocument_PrintPage(ByVal sender As Object, ByVal e As System.Drawing.Printing.PrintPageEventArgs)

        ' This event fires whenever a new page needs to be printed ...

        ' declare local variables ...
        Dim strLine As String

        ' line count should be set to zero for a new page            
        mintLineCount = 0

        ' Work out the number of lines per page. Use the MarginBounds
        ' on the event to do this...
        msngLinesPerPage = e.MarginBounds.Height / mobjPrintFont.GetHeight(e.Graphics)
        ' set the left and top margins ...
        msngLeftMargin = e.MarginBounds.Left
        msngTopMargin = e.MarginBounds.Top

        ' print the report headings
        PrintHeadings(e)

        ' Process input records as long as there is room on the page and
        ' end-of-file has not been reached ...
        While (mintLineCount < msngLinesPerPage And Not EOF(mintCustFileNbr))

            ' input a "record's worth" of fields from the input file ...
            Input(mintCustFileNbr, mstrLastName)
            Input(mintCustFileNbr, mstrFirstName)
            Input(mintCustFileNbr, mstrAddr)
            Input(mintCustFileNbr, mstrCity)
            Input(mintCustFileNbr, mstrState)
            Input(mintCustFileNbr, mstrZip)

            ' prepare the detail line ...                
            strLine = (mstrFirstName & " " & mstrLastName).PadRight(21) _
                    & mstrAddr.PadRight(28) _
                    & mstrCity.PadRight(25) _
                    & mstrState.PadRight(3) _
                    & mstrZip

            ' print the detail line
            PrintReportLine(strLine, e)

        End While

        ' as long as there are more records to process, keep invoking this event            
        e.HasMorePages = Not (EOF(mintCustFileNbr))

    End Sub

    Private Sub PrintHeadings(ByVal e As System.Drawing.Printing.PrintPageEventArgs)

        Dim strLine As String

        mintPageCount = mintPageCount + 1

        strLine = "Print Date: " _
                & Format(Today, "MM/dd/yy").PadRight(18) _
                & "The VB Programmer, LLC".PadRight(42) _
                & "Page: " _
                & CStr(mintPageCount).PadLeft(3)
        PrintReportLine(strLine, e)

        strLine = "Print Time: " _
                & Format(TimeOfDay, "hh:mm:ss").PadRight(20) _
                & "CUSTOMER LIST"
        PrintReportLine(strLine, e)

        mintLineCount = mintLineCount + 1

        strLine = "CUSTOMER NAME".PadRight(21) _
                & "ADDRESS".PadRight(28) _
                & "CITY".PadRight(25) _
                & "ST".PadRight(3) _
                & "ZIP"
        PrintReportLine(strLine, e)

        strLine = "-------------".PadRight(21) _
                & "-------".PadRight(28) _
                & "----".PadRight(25) _
                & "--".PadRight(3) _
                & "---"
        PrintReportLine(strLine, e)

        mintLineCount = mintLineCount + 1

    End Sub

    Private Sub PrintReportLine(ByVal pstrLine As String, ByVal e As System.Drawing.Printing.PrintPageEventArgs)

        ' Calculate the vertical position on the page...
        msngVerticalPosition = msngTopMargin _
                             + (mintLineCount * mobjPrintFont.GetHeight(e.Graphics))

        ' Pass the string to be printed to DrawString ...
        e.Graphics.DrawString(pstrLine, _
                              mobjPrintFont, _
                              Brushes.Black, _
                              msngLeftMargin, _
                              msngVerticalPosition, _
                              New StringFormat())

        ' Increment the line count...
        mintLineCount = mintLineCount + 1

    End Sub

End Class
